@@ -1,15 +1,15 @@
-# -*- coding: utf-8 -*-
 
 """
 
 __init__.py
 
-Author: Rob Cakebread <gentoodev a t gmail.com>
+Author: Rob Cakebread <gentoodev@gmail.com>
 
 License  : GNU General Public License Version 2
 
 """
 
 __docformat__ = 'restructuredtext'
+__version__ = '0.3.0'
 
 
