@@ -12,11 +12,12 @@ License  : GNU General Public License Version 2
 """
 
 
+from yolk.yolklib import Distributions
+
 from setuptools.package_index import PackageIndex
 import pkg_resources
 
 
-
 __docformat__ = 'restructuredtext'
 
 
@@ -49,8 +50,9 @@ def get_download_uri(package_name, version, source):
     """
     Use setuptools to search for a package's URI
     
-    @returns: list of URI strings 
+    @returns: URI string
     """
+    #print package_name, version, source
     tmpdir = None
     force_scan = True
     develop_ok = False
@@ -61,12 +63,35 @@ def get_download_uri(package_name, version, source):
         pkg_spec = package_name
     req = pkg_resources.Requirement.parse(pkg_spec)
     pkg_index = MyPackageIndex()
-    output = []
     try:
         pkg_index.fetch_distribution(req, tmpdir, force_scan, source, 
                 develop_ok)
     except DownloadURI, url:
-        if url.value not in output:
-            #Remove #egg=pkg-dev
-            output.append(url.value.split("#")[0])
-    return output
+        #Remove #egg=pkg-dev
+        clean_url = url.value.split("#")[0]
+        #If setuptools is asked for an egg and there isn't one, it will
+        #return source if available, which we don't want.
+        if not source and not clean_url.endswith(".egg") and \
+                not clean_url.endswith(".EGG"):
+            return
+        else:
+            return clean_url
+
+def get_pkglist():
+    """
+    Return list of all installed packages
+
+    Note: It returns one project name per pkg no matter how many versions
+    of a particular package is installed
+     
+    @returns: list of project name strings for every installed pkg
+    
+    """
+
+    dists = Distributions()
+    projects = []
+    for (dist, active) in dists.get_distributions("all"):
+        if dist.project_name not in projects:
+            projects.append(dist.project_name)
+    return projects
+
